package Evo::EA::Graph;

sub new {
	my ($class) = @_;

	my $self = { node => GraphNode->new( () ), };

	$class = ref($class) || $class;

	bless $self, $class;
}

1;
